@@ -245,7 +245,7 @@ sub visit_XSD_ComplexType {
     if ( grep { $_ eq $content_model} qw(all sequence choice) )
     {
         # visit child elements
-        for (@{ $type->get_element() }) {
+        for (@{ $type->get_element() || [] }) {
             $_->_accept( $self );
         }
         return;
