@@ -4,7 +4,7 @@ use warnings;
 use Class::Std::Fast::Storable constructor => 'none';
 use base qw(SOAP::WSDL::Base);
 
-use version; our $VERSION = qv('2.00.10');
+our $VERSION=q{2.00_29};
 
 #<attribute
 #  default = string
@@ -19,17 +19,14 @@ use version; our $VERSION = qv('2.00.10');
 #  Content: (annotation?, (simpleType?))
 #</attribute>
 
-# id provided by Base
-# name provided by Base
-# annotation provided by Base
 
 my %default_of      :ATTR(:name<default>    :default<()>);
 my %fixed_of        :ATTR(:name<fixed>      :default<()>);
-my %form_of         :ATTR(:name<form>       :default<()>);
-
+my %form_of         :ATTR(:name<form>      :default<()>);
+# id provided by Base
+# name provided by Base
 my %type_of         :ATTR(:name<type>       :default<()>);
-my %use_of          :ATTR(:name<use>        :default<()>);
-my %ref_of          :ATTR(:name<ref>        :default<()>);
+my %use_of          :ATTR(:name<use>      :default<()>);
 
 # may be defined as atomic simpleType
 my %simpleType_of   :ATTR(:name<simpleType> :default<()>);
